@@ -1,6 +1,6 @@
 import pytest
 
-pytestmark = pytest.mark.asyncio(scope="package")
+pytestmark = pytest.mark.asyncio(loop_scope="session")
 
 
 async def test_get_detail(songlist):
