@@ -2,7 +2,7 @@ import pytest
 
 from qqmusic_api.top import get_top_category
 
-pytestmark = pytest.mark.asyncio(scope="package")
+pytestmark = pytest.mark.asyncio(loop_scope="session")
 
 
 async def test_top_category(top):
